% Supplementary data for the paper
% Bazilinskyy, P., Kyriakidis, M., Dodou, D., & De Winter, J. C. F. (2019). When will most cars be able to drive fully automatically? Projections of 18,970 survey respondents. Transportation Research Part F.
% Tested in MATLAB R2018b

clear variables;close all;clc
FLAG=0; % if FLAG = 1 then read raw data from Excel
nrsurveys=15;
TH=25; % threshold for respondents per country
S10_countries={'AUS' 'AUT' 'BEL' 'CAN' 'CHE' 'DEU' 'DNK' 'FIN' 'FRA' 'GBR' 'ITA' 'NLD' 'NOR' 'SWE' 'USA'};
if FLAG==1
    rng('shuffle');RND=ceil(10^6*rand); % random number for scrambling worker ID
    N=NaN(nrsurveys,10);
    disp('READING AND FILTERING THE INDIVIDUAL SURVEYS')
    for survey=1:nrsurveys
        clear XSM raw raw0
        disp(['SURVEY = ' num2str(survey)])
        if survey==1
            FILENAME='f470778_survey1pilot.xlsx'; % pilot measurement
            [~,~,raw0]=xlsread(FILENAME,'A2:AB11');
            FILENAME='f473063_survey1.xlsx'; % eventual measurement
            [~,~,raw]=xlsread(FILENAME,'A2:AB1853');
            IS=intersect(cell2mat(raw(:,8)),cell2mat(raw0(:,8)));
            raw=raw(~ismember(cell2mat(raw(:,8)),IS),:); % remove people who participated in pilot survey
            raw=[raw0;raw]; %#ok<AGROW>
            temp=raw(:,15);S1_google=1*strcmp(temp,'No')+2*strcmp(temp,'Yes')-1*strcmp(temp,'No response');
        elseif survey==2
            FILENAME='f499047_survey2.xlsx';
            [~,~,raw]=xlsread(FILENAME,'A2:CD5001');
            temp=raw(:,72);S2_education=1*strcmp(temp,'No school completion')+2*strcmp(temp,'Primary school')+3*strcmp(temp,'Secondary school')+4*strcmp(temp,'Vocational school')+5*strcmp(temp,'Higher Education - BSc')+6*strcmp(temp,'Higher Education - MSc')+7*strcmp(temp,'Higher Education - PhD')-1*strcmp(temp,'I prefer not to respond')-2*strcmp(temp,'Other'); % What is the highest degree or level of education you have completed?
            temp=raw(:,75);S2_income=1*strcmp(temp,'I do not have any income')+2*strcmp(temp,'0 - 500 USD (0 - 367 Euro)')+3*strcmp(temp,'501 - 1,000 USD (368 - 735 Euro)')+4*strcmp(temp,'1,001 - 5,000  (736 - 3,675 Euro)')+5*strcmp(temp,'5,001 - 10,000  (3,676 - 7,350 Euro)')+6*strcmp(temp,'10,001 - 20,000 USD (7,351 - 14,700 Euro)')+7*strcmp(temp,'20,001 - 30,000 USD (14,701 - 22,050 Euro)')+8*strcmp(temp,'30,001 - 40,000  (22,051 - 29,400 Euro)')+9*strcmp(temp,'40,001 - 50,000  (29,401 - 36,745 Euro)')+10*strcmp(temp,'50,001 - 60,000 USD (36,746 - 44,100 Euro)')+11*strcmp(temp,'60,001 - 80,000  (44,101 - 58, 800 Euro)')+12*strcmp(temp,'80,001 - 100,000  (58,801 - 73,500 Euro)')+13*strcmp(temp,'100,001 - 150,000 USD (73,501 - 110,000 Euro)')+14*strcmp(temp,'More than 150,000 USD (More than 110,000 Euro)')-1*strcmp(temp,'I prefer not to respond'); % What is your personal gross annual income in USD? (USD = United States Dollar)
        elseif survey==3
            FILENAME='f605379_survey3_1.xlsx';
            [~,~,raw]=xlsread(FILENAME,'A2:AS2001');
        elseif survey==4
            FILENAME='f653982_survey4_test.xlsx';
            [~,~,raw0]=xlsread(FILENAME,'A2:AJ11');
            FILENAME='f653982_survey4_1.xlsx';
            [~,~,raw]=xlsread(FILENAME,'A2:AJ2997');
            IS=intersect(cell2mat(raw(:,8)),cell2mat(raw0(:,8)));
            raw=raw(~ismember(cell2mat(raw(:,8)),IS),:); % remove people who participated in pilot survey
            raw=[raw0;raw]; %#ok<AGROW>
        elseif survey==5
            FILENAME='f708362_survey5.xlsx';
            [~,~,raw]=xlsread(FILENAME,'A2:CA3001');
        elseif survey==6
            FILENAME='f845505_4.xlsx';
            [~,~,raw]=xlsread(FILENAME,'A2:AB3251');
            temp=raw(:,15);S6_google=1*strcmp(temp,'no')+2*strcmp(temp,'yes')-1*strcmp(temp,'no_response');
        elseif survey==7
            FILENAME='Pilot100_survey7.xlsx'; % pilot measurement with 100 people
            [~,~,raw0]=xlsread(FILENAME,'A2:CW101');
            FILENAME='Full3053_survey7.xlsx';
            [~,~,raw]=xlsread(FILENAME,'A2:CW3054');
            IS=intersect(cell2mat(raw(:,8)),cell2mat(raw0(:,8))); % people who participated in both surveys
            raw=raw(~ismember(cell2mat(raw(:,8)),IS),:); % remove people from main survey who already participated in pilot survey
            raw=[raw0;raw]; %#ok<AGROW> % merge both measurements
        elseif survey==8
            FILENAME='f993745_survey8.xlsx';
            [~,~,raw]=xlsread(FILENAME,'A2:U701');
            [~,~,rawSM1]=xlsread('Survey8_Surveymonkey1.xlsx','A3:L164');
            [~,~,rawSM2]=xlsread('Survey8_Surveymonkey2.xlsx','A3:L178');
            [~,~,rawSM3]=xlsread('Survey8_Surveymonkey3.xlsx','A3:L165');
            [~,~,rawSM4]=xlsread('Survey8_Surveymonkey4.xlsx','A3:L169');
            [~,~,rawSM5]=xlsread('Survey8_Surveymonkey5.xlsx','A3:L173');
            rawSM=[rawSM1;rawSM2;rawSM3;rawSM4;rawSM5];
            XSM=NaN(size(rawSM,1),3);
            IPCF=NaN(size(raw,1),1);for i=1:size(raw,1);try IPCF(i)=str2double(strrep(raw(i,12),'.',''));catch;IPCF(i)=cell2mat(raw(i,12));end;end % reduce IP addresses of CrowdFlower to a single number
            IPSM=NaN(size(rawSM,1),1);for i=1:size(rawSM,1);IPSM(i)=str2double(strrep(rawSM(i,5),'.',''));end % reduce IP addresses of SurveyMonkey to a single number
            temp=rawSM(:,11);XSM(:,2)=1*strcmp(temp,'Female')+2*strcmp(temp,'Male'); % Gender
            temp=rawSM(:,12);for i=1:length(temp);try if strcmp(temp(i),'?');XSM(i,3)=NaN;else;XSM(i,3)= cell2mat(temp(i));end;catch error;XSM(i,3)=NaN;end;end % Age
            XSM(230,3)=28; % manual imputation for a participant who reported "28 year"
            temp=rawSM(:,10);XSM(:,1)=strcmp(temp,'No')+2*strcmp(temp,'Yes'); % Instructions understood
            XSM(XSM<=0)=NaN; % Put missing values (0) or no response (-1) at NaN
        elseif survey==9
            FILENAME='f995316_survey9.xlsx';
            [~,~,raw]=xlsread(FILENAME,'A2:AH2001');
        elseif survey==10
            FILENAME='f995185_survey10.xlsx';
            [~,~,raw]=xlsread(FILENAME,'A2:P701');
            [~,~,rawSM1]=xlsread('Survey10_Surveymonkey1.xlsx','A3:L151');
            [~,~,rawSM2]=xlsread('Survey10_Surveymonkey2.xlsx','A3:L163');
            [~,~,rawSM3]=xlsread('Survey10_Surveymonkey3.xlsx','A3:L159');
            [~,~,rawSM4]=xlsread('Survey10_Surveymonkey4.xlsx','A3:L163');
            [~,~,rawSM5]=xlsread('Survey10_Surveymonkey5.xlsx','A3:L169');
            rawSM=[rawSM1;rawSM2;rawSM3;rawSM4;rawSM5];
            XSM=NaN(size(rawSM,1),3);
            IPCF=NaN(size(raw,1),1);for i=1:size(raw,1);try IPCF(i)=str2double(strrep(raw(i,16),'.',''));catch;IPCF(i)=cell2mat(raw(i,16));end;end % reduce IP addresses of CrowdFlower to a single number
            IPSM=NaN(size(rawSM,1),1);for i=1:size(rawSM,1);IPSM(i)=str2double(strrep(rawSM(i,5),'.',''));end % reduce IP addresses of SurveyMonkey to a single number
            temp=rawSM(:,11);XSM(:,2)=1*strcmp(temp,'Female')+2*strcmp(temp,'Male'); % Gender
            temp=rawSM(:,12);for i=1:length(temp);try if strcmp(temp(i),'?');XSM(i,3)=NaN;else;XSM(i,3)= cell2mat(temp(i));end;catch error;XSM(i,3)=NaN;end;end % Age
            temp=rawSM(:,10);XSM(:,1)=strcmp(temp,'No')+2*strcmp(temp,'Yes'); % Instructions understood
            XSM(XSM<=0)=NaN; % Put missing values (0) or no response (-1) at NaN
        elseif survey==11
            FILENAME='f1013422_Survey11.xlsx';
            [~,~,raw]=xlsread(FILENAME,'A2:AC2501');
            temp=raw(:,15);S11_google=1*strcmp(temp,'no')+2*strcmp(temp,'yes')-1*strcmp(temp,'no_response');
            temp=raw(:,16);S11_tesla=1*strcmp(temp,'no')+2*strcmp(temp,'yes')-1*strcmp(temp,'no_response');
        elseif survey==12
            [~,~,raw]=xlsread('f1023550_SWOV_PHOTO_CROWDFLOWER.xlsx','A2:U701');
            [~,~,rawSM]=xlsread('Cyclists behaviour when interacting with automated vehicles.xlsx','A2:L729');
            XSM=NaN(size(rawSM,1),3);
            IPCF=NaN(size(raw,1),1);for i=1:size(raw,1);try IPCF(i)=str2double(strrep(raw(i,12),'.',''));catch;IPCF(i)=cell2mat(raw(i,12));end;end % reduce IP addresses of CrowdFlower to a single number
            IPSM=NaN(size(rawSM,1),1);for i=1:size(rawSM,1);IPSM(i)=str2double(strrep(rawSM(i,6),'.',''));end % reduce IP addresses of SurveyMonkey to a single number
            XSM(:,2)=3-cell2mat(rawSM(:,12)); % Gender (1 = Female, 2 = Male)
            XSM(:,3)=str2double(rawSM(:,11)); % Age
            XSM(XSM<=0)=NaN; % Put missing values (0) or no response (-1) at NaN
        elseif survey==13
            FILENAME='f1258363_survey13.xlsx';
            [~,~,raw]=xlsread(FILENAME,'A2:AC3001');
            temp=raw(:,15);S13_google=1*strcmp(temp,'no')+2*strcmp(temp,'yes')-1*strcmp(temp,'no_response');
            temp=raw(:,16);S13_tesla=1*strcmp(temp,'no')+2*strcmp(temp,'yes')-1*strcmp(temp,'no_response');
        elseif survey==14
            FILENAME='f1307310_survey14.xlsx';
            [~,~,raw]=xlsread(FILENAME,'A2:DT1771');
            temp=raw(:,15);S13_google=1*strcmp(temp,'no')+2*strcmp(temp,'yes')-1*strcmp(temp,'no_response');
            temp=raw(:,16);S13_tesla=1*strcmp(temp,'no')+2*strcmp(temp,'yes')-1*strcmp(temp,'no_response');
        elseif survey==15
            FILENAME='f1333663_survey15.xlsx';
            [~,~,raw]=xlsread(FILENAME,'A2:DJ2001');
            temp=raw(:,15);S13_google=1*strcmp(temp,'no')+2*strcmp(temp,'yes')-1*strcmp(temp,'no_response');
            temp=raw(:,16);S13_tesla=1*strcmp(temp,'no')+2*strcmp(temp,'yes')-1*strcmp(temp,'no_response');
        end
        
        V= [16 9 28 27 25 2 12 8 % 1 = instructions understood, 2 = country, 3 = gender, 4 = age, 5 = year, 6 = survey time, 7 = IP, 8 = worker ID
            21 9 74 73 48 2 12 8 % 2
            17 8 41 40 34 2 11 7 % 3
            32 9 36 35 33 2 12 8 % 4
            29 9 63 62 50 2 12 8 % 5
            16 9 28 27 25 2 12 8 % 6
            25 9 78 77 34 2 12 8 % 7
            13 9 -1 -1 14 2 12 8 % 8
            4 31 20 19 16 25 34 30 % 9
            2 13 -1 -1  3 7 16 12 % 10
            17 9 29 28 26 2 12 8 % 11
            13 9 -1 -1 14 2 12 8 % 12
            17 9 29 28 26 2 12 8 % 13
            16 9 63 62 29 2 12 8 % 14
            16 9 80 79 29 2 12 8]; % 15
        i1=V(survey,1);i2=V(survey,2);i3=V(survey,3);i4=V(survey,4);i5=V(survey,5);i6=V(survey,6);i7=V(survey,7);i8=V(survey,8);
        
        disp(['Number of respondents = ' num2str(size(raw,1))])
        N(survey,1)=size(raw,1);
        X=NaN(size(raw,1),3);
        if survey==8 || survey==10 || survey==12 % SurveyMonkey
            for i=1:size(raw,1)
                temp=find(IPSM==IPCF(i)); % if the IP address is available in both surveys
                if length(temp)>1;temp=temp(1);end % use first IP address
                if length(temp)==1
                    X(i,2:3)=XSM(temp,2:3); % Instructions understood, Gender, Age
                end
            end
        end
        temp=raw(:,i1);X(:,1)=strcmp(temp,'no')+strcmp(temp,'No')+2*strcmp(temp,'Yes')+2*strcmp(temp,'yes')-1*strcmp(temp,'No response')-1*strcmp(temp,'I prefer not to respond'); % Instructions understood
        temp=raw(:,i2);Country=cell(size(X,1),1);for i=1:length(temp);try Country(i)=unique(temp(i));catch error;Country(i)={'NaN'};end;end % Country
        if i3>0;temp=raw(:,i3);X(:,2)=1*strcmp(temp,'Female')+1*strcmp(temp,'female')+2*strcmp(temp,'Male')+2*strcmp(temp,'male')-1*strcmp(temp,'No response')-1*strcmp(temp,'I prefer not to respond');end % Gender
        if i4>0;temp=raw(:,i4);for i=1:length(temp);try if strcmp(temp(i),'?');X(i,3)=NaN;else;X(i,3)= cell2mat(temp(i));end;catch error;X(i,3)=NaN;end;end;end % Age
        temp=raw(:,i5);for i=1:length(temp);try if strcmp(temp(i),'?');X(i,4)=NaN;else;X(i,4)=cell2mat(temp(i));end;catch error;X(i,4)=NaN;end;end % Year automated driving on roads
        temp=raw(:,i5);for i=1:length(temp);try if strcmpi(raw(i,i5),'never');X(i,7)=1;X(i,4)=9999.0001;end;catch error;X(i,4)=NaN;end;end % Year automated driving on roads (Participant reports 'never')
        
        if survey==8 || survey ==12
            temp1=raw(:,i6);temp2=raw(:,i6+2);for i=1:length(temp1);try X(i,5)=24*3600*(datenum(temp1(i))-datenum(temp2(i)));catch error;X(i,5)=0;end;end % Survey time
        elseif survey==9 || survey==10
            temp1=raw(:,i6);temp2=raw(:,i6+1);for i=1:length(temp1);try X(i,5)=24*3600*(datenum(temp1(i))-datenum(temp2(i)));catch error;X(i,5)=0;end;end % Survey time
        else
            temp1=raw(:,i6);temp2=raw(:,i6+2);for i=1:length(temp1);try X(i,5)=24*3600*(datenum(temp1(i))-datenum(temp2(i)));catch error;X(i,5)=0;end;end % Survey time
        end
        X(:,5)=tiedrank(X(:,5))./size(X,1); % normalize survey time to make it comparable between surveys.
        X(:,6)=round(cell2mat(raw(:,i8))+RND).^1.5; % scramble the worker ID to make it fully anonymous
        
        % DBQ
        if ismember(survey,[2 4 8 10 12]) % no DBQ survey
            X(:,8:14)=NaN;
        elseif survey==1
            temp=raw(:,18:24);X(:,8:14)=1*strcmp(temp,'Never')+2*strcmp(temp,'Hardly ever')+3*strcmp(temp,'Occasionally')+4*strcmp(temp,'Quite often')+5*strcmp(temp,'Frequently')+6*strcmp(temp,'Nearly all the time')-1*strcmp(temp,'No response'); % DBQ violations
        elseif survey==3
            temp=raw(:,19:25);X(:,8:14)=1*strcmp(temp,'0 times per month')+2*strcmp(temp,'1 to 3 times per month')+3*strcmp(temp,'4 to 6 times per month')+4*strcmp(temp,'7 to 9 times per month')+5*strcmp(temp,'10 or more times per month')-1*strcmp(temp,'I prefer not to respond'); % DBQ violations
        elseif survey==5
            temp=raw(:,31:37);X(:,8:14)=1*strcmp(temp,'0 times per month')+2*strcmp(temp,'1 to 3 times per month')+3*strcmp(temp,'4 to 6 times per month')+4*strcmp(temp,'7 to 9 times per month')+5*strcmp(temp,'10 or more times per month')-1*strcmp(temp,'I prefer not to respond'); % DBQ violations
        elseif survey==6
            temp=raw(:,18:24);X(:,8:14)=1*strcmp(temp,'never')+2*strcmp(temp,'hardly_ever')+3*strcmp(temp,'occasionally')+4*strcmp(temp,'quite_often')+5*strcmp(temp,'frequently')+6*strcmp(temp,'nearly_all_the_time')-1*strcmp(temp,'no_response'); % DBQ violations
        elseif survey==7
            temp=raw(:,27:33);X(:,8:14)=1*strcmp(temp,'0_times_per_month')+2*strcmp(temp,'1_to_3_times_per_month')+3*strcmp(temp,'4_to_6_times_per_month')+4*strcmp(temp,'7_to_9_times_per_month')+5*strcmp(temp,'10_or_more_times_per_month')-1*strcmp(temp,'i_prefer_not_to_respond'); % DBQ violations
        elseif survey==9
            temp=raw(:,6:12);X(:,8:14)=1*strcmp(temp,'0_times_per_month')+2*strcmp(temp,'1_to_3_times_per_month')+3*strcmp(temp,'4_to_6_times_per_month')+4*strcmp(temp,'7_to_9_times_per_month')+5*strcmp(temp,'10_or_more_times_per_month')-1*strcmp(temp,'i_prefer_not_to_respond'); % DBQ violations
        elseif survey==11
            temp=raw(:,19:25);X(:,8:14)=1*strcmp(temp,'never')+2*strcmp(temp,'hardly_ever')+3*strcmp(temp,'occasionally')+4*strcmp(temp,'quite_often')+5*strcmp(temp,'frequently')+6*strcmp(temp,'nearly_all_the_time')-1*strcmp(temp,'no_response'); % DBQ violations
        elseif survey==13
            temp=raw(:,19:25);X(:,8:14)=1*strcmp(temp,'never')+2*strcmp(temp,'hardly_ever')+3*strcmp(temp,'occasionally')+4*strcmp(temp,'quite_often')+5*strcmp(temp,'frequently')+6*strcmp(temp,'nearly_all_the_time')-1*strcmp(temp,'no_response'); % DBQ violations
        elseif survey==14
            temp=raw(:,18:24);X(:,8:14)=1*strcmp(temp,'0 times per month')+2*strcmp(temp,'1 to 3 times per month')+3*strcmp(temp,'4 to 6 times per month')+4*strcmp(temp,'7 to 9 times per month')+5*strcmp(temp,'10 or more times per month')-1*strcmp(temp,'I prefer not to respond'); % DBQ violations
        elseif survey==15
            temp=raw(:,18:24);X(:,8:14)=1*strcmp(temp,'0 times per month')+2*strcmp(temp,'1 to 3 times per month')+3*strcmp(temp,'4 to 6 times per month')+4*strcmp(temp,'7 to 9 times per month')+5*strcmp(temp,'10 or more times per month')-1*strcmp(temp,'I prefer not to respond'); % DBQ violations
        end
        if ~ismember(survey,[2 4 8 10 12 14]) % if DBQ survey, then display number of respondents per DBQ item
            disp(unique(X(:,8:14)))
            
        end
        X(X<=0)=NaN; % Put missing values (0) or no response (-1) at NaN
        X(isnan(sum(X(:,8:14),2)),8:14)=NaN; % for the DBQ put all 7 items at NaN if any of the 7 items is NaN
        X(:,8:14)=tiedrank(X(:,8:14))./repmat(sum(~isnan(X(:,8:14))),size(X,1),1); % ranking of DBQ scores so that these scores become comparable between surveys
        
        if survey==2
            X(:,15)=S2_education;
            X(:,16)=S2_income;
        elseif survey==1
            X(:,15)=S1_google;
        elseif survey==6
            X(:,15)=S6_google;
        elseif survey==11
            X(:,15)=S11_google;
            X(:,16)=S11_tesla;
        elseif survey==13
            X(:,15)=S13_google;
            X(:,16)=S13_tesla;
        else
            X(:,15:16)=NaN;
        end
        
        invalid1=find(X(:,1)<2); % respondents who did not read instructions ot who indicated 'I prefer not to respond'
        invalid2=find(X(:,3)<18); % respondents who indicated they are under 18 years old
        invalid3=find(X(:,3)>110); % respondents who indicated they are older than 110
        invalid4=find(isnan(sum(X(:,1:3),2))); % respondents who give 'no response'
        invalid5=find(strcmp(Country,'NaN') | strcmp(Country,'A1'));
        y = NaN(size(X(:,1)));
        IPCF=NaN(size(raw,1),1);for i=1:size(raw,1);try IPCF(i)=str2double(strrep(raw(i,i7),'.',''));catch;IPCF(i)=cell2mat(raw(i,i7));end;end % reduce IP addresses of CrowdFlower to a single number
        for i=1:size(X,1)
            temp=find(IPCF==IPCF(i));
            if length(temp)==1 % if the IP address occurs only once
                y(i)=1; % keep
            elseif length(temp)>1 % if the IP addres occurs more than once
                y(temp(1))=1; % keep the first survey for that IP address
                y(temp(2:end))=2; % no not keep the other ones
            end
        end
        invalid6=find(y>1); % respondents who completed the survey more than once (i.e., remove the doublets)
        invalid7=find(X(:,5)<.05); % fastest 5% of the respondents
        invalid= unique([invalid1;invalid2;invalid3;invalid4;invalid5;invalid6;invalid7]); % all invalid respondents
        X(invalid,:)=[];% remove invalid respondents
        Country(invalid)=[];
        
        disp(['Number of respondents who did not read instructions: ' num2str(length(invalid1))])
        disp(['Number of respondents under 18: ' num2str(length(invalid2))])
        disp(['Number of respondents above 110: ' num2str(length(invalid3))])
        disp(['Number of respondents with no response for gender or age: ' num2str(length(invalid4))])
        disp(['Number of respondents with no country identified: ' num2str(length(invalid5))])
        disp(['Number of respondents more than once from the same IP address: ' num2str(length(invalid6))])
        disp(['Number of respondents in any of these categories: ' num2str(length(invalid))])
        disp(['Number of respondents included in the analysis: ' num2str(size(X,1))]);
        disp(['Number of countries included in the analysis: ' num2str(length(unique(Country)))])
        N(survey,2)=length(invalid1);
        N(survey,3)=length(invalid2);
        N(survey,4)=length(invalid3);
        N(survey,5)=length(invalid4);
        N(survey,6)=length(invalid5);
        N(survey,7)=length(invalid6);
        N(survey,8)=length(invalid);
        N(survey,9)=size(X,1);
        N(survey,10)=length(unique(Country));
        eval(['X' num2str(survey) '=X;Country' num2str(survey) '=Country;save(''survey' num2str(survey) '.mat'',''X' num2str(survey) ''',''Country' num2str(survey) ''')'])
    end
end
%% Loop for all contries, USA, IND, VEN
close all
for C=1:4
    Y=NaN(nrsurveys,14);
    
    if C==2
        disp('United states')
    elseif C==3
        disp('India')
    elseif C==4
        disp('Venezuela')
    end
    for survey=1:nrsurveys
        load(['survey' num2str(survey) '.mat']);
        
        eval(['X' num2str(survey) '(X' num2str(survey) '(:,4)<2014,4)=NaN;']); % put years < 2014 at NaN
        eval(['temp=X' num2str(survey) ';'])
        eval(['temp2=Country' num2str(survey) ';'])
        
        switch C
            case 2
                temp=temp(strcmp(temp2,'USA'),:);
            case 3
                temp=temp(strcmp(temp2,'IND'),:);
            case 4
                temp=temp(strcmp(temp2,'VEN'),:);
        end
        Y(survey,:)=[length(temp) length(unique(temp2)) sum(temp(:,4)>0 & temp(:,4)~=9999.0001) nansum(temp(:,7))  ...
            prctile(temp(:,4),25) prctile(temp(:,4),50) prctile(temp(:,4),75)...
            (100*sum(temp(:,4)==2020)./sum(~isnan(temp(:,4))))  ...
            (100*sum(temp(:,4)==2030)./sum(~isnan(temp(:,4)))) (100*sum(temp(:,4)<=2029 & temp(:,4)>=2017)./sum(~isnan(temp(:,4)))) ...
            (100*sum(temp(:,4)>=2075)./sum(~isnan(temp(:,4)))) (100*mean(temp( temp(:,4)>0,2)-1)) mean(temp(temp(:,4)>0,3)) std(temp(temp(:,4)>0,3))];
        
        eval(['X' num2str(survey) 'mark=[' num2str(survey) '*(ones(length(X' num2str(survey) '),1)) X' num2str(survey) '];'])
        eval(['if size(X' num2str(survey) 'mark,2)==15;X' num2str(survey) 'mark(:,16:17)=NaN;end'])
        eval(['if size(X' num2str(survey) 'mark,2)==16;X' num2str(survey) 'mark(:,17)=NaN;end'])
        eval(['if size(X' num2str(survey) ',2)==14;X' num2str(survey) '(:,15:16)=NaN;end'])
        eval(['if size(X' num2str(survey) ',2)==15;X' num2str(survey) '(:,16)=NaN;end'])
        
        if survey==2 && C==1  % calculate correlations within Survey 2
            Country2b=Country2;
            temp=X2(:,[4 15 16]);
            temp(temp<0)=NaN;
            Country2b(isnan(sum(temp,2)))=[];
            temp(isnan(sum(temp,2)),:)=[];
            Country2U=unique(Country2b); NC2=NaN(length(Country2U),1);for i=1:length(Country2U);NC2(i)=sum(strcmp(Country2,Country2U(i)));end % NC2 is a vector containing the number of participants per country in Survey 2
            Country2U=Country2U(NC2>=TH); % Countries in Survey 2 with 25 or more respondents
            
            Corr2=NaN(length(Country2U),size(temp,2),size(temp,2));
            for i=1:length(Country2U)
                temp2=strcmp(Country2b,Country2U(i));
                Corr2(i,:,:)=corr(temp(temp2,:),'type','spearman');
            end
            disp('Median Spearman rank-order correlations between 1. year, 2. education category, 3. income category')
            disp(round(squeeze(median(Corr2,1)),2))
            disp('Number of countries for calculating these correlations')
            disp(length(Country2U))
        end
        if survey==1 && C==1
            temp=X1(:,15);temp(temp<0)=NaN;
            disp(['Percentage of people who have heard of the Google Driverless car = ' num2str(100*(nanmean(temp)-1)) ', Survey nr = ' num2str(survey)])
        end
        if survey==6 && C==1
            temp=X6(:,15);temp(temp<0)=NaN;
            disp(['Percentage of people who have heard of the Google Driverless car = ' num2str(100*(nanmean(temp)-1)) ', Survey nr = ' num2str(survey)])
        end
        if survey==11 && C==1
            temp=X11(:,15);temp(temp<0)=NaN;
            disp(['Percentage of people who have heard of the Google Driverless car = ' num2str(100*(nanmean(temp)-1)) ', Survey nr = ' num2str(survey)])
            temp=X11(:,16);temp(temp<0)=NaN;
            disp(['Percentage of people who have heard of the Tesla Autopilot = ' num2str(100*(nanmean(temp)-1)) ', Survey nr = ' num2str(survey)])
        end
        if survey==13 && C==1
            temp=X13(:,15);temp(temp<0)=NaN;
            disp(['Percentage of people who have heard of the Google Driverless car = ' num2str(100*(nanmean(temp)-1)) ', Survey nr = ' num2str(survey)])
            temp=X13(:,16);temp(temp<0)=NaN;
            disp(['Percentage of people who have heard of the Tesla Autopilot = ' num2str(100*(nanmean(temp)-1)) ', Survey nr = ' num2str(survey)])
        end
    end
    Y(isnan(Y(:,end)),3:4)=1;Y(isnan(Y(:,end)),5:end)=-9999; % impute -9999 in case there are no respondents for that country
    
    printmat(Y,'Descriptive statistics regarding reported year per survey','S1 S2 S3 S4 S5 S6 S7 S8 S9 S10 S11 S12 S13 S14 S15','# #Ctry #Year #never P25 P50 P75 %2020 %2030 %2017-2029 %2075+ %Males Mage SDAge')
    D=[datenum('16 jun 2014') datenum('4 jul 2014') datenum('2 sep 2014') datenum('29 nov 2014') datenum('31 mar 2015') ...
        datenum('24 dec 2015') datenum('30 may 2016') datenum('27 feb 2017') datenum('3 mar 2017') datenum('4 mar 2017')  ...
        datenum('16 jun 2017') datenum('7 jul 2017') datenum('19 apr 2018') datenum('3 oct 2018') datenum('25 dec 2018')];
    figure;hold on
    for i=1:length(D)
        h=scatter(D(i),Y(i,8),(sum(Y(i,3:4),2)),[0 144 189]/255,'filled');
        alpha(h,.5)
    end
    set(gca,'xtick',[datenum('1 jan 2014') datenum('1 jul 2014') datenum('1 jan 2015') datenum('1 jul 2015') datenum('1 jan 2016') datenum('1 jul 2016') datenum('1 jan 2017') datenum('1 jul 2017') datenum('1 jan 2018') datenum('1 jul 2018') datenum('1 jan 2019')]);
    set(gca,'xticklabel',{'Jan 14' 'Jul 14' 'Jan 15' 'Jul 15' 'Jan 16' 'Jul 16' 'Jan 17' 'Jul 17' 'Jan 18' 'Jul 18' 'Jan 19'})
    set(gca,'xlim',[datenum('1 jan 2014') datenum('1 mar 2019')])
    if C==1
        set(gca,'pos',[0.04 0.08 0.5 0.90],'ylim',[0 25])
    else
        set(gca,'pos',[0.04 0.08 0.5 0.88],'ylim',[0 37])
    end
    if C==2
        title('United States')
    elseif C==3
        title('India')
    elseif C==4
        title('Venezuela')
    end
    grid on;box on
    xlabel('Date of survey')
    ylabel('Percentage of respondents reporting 2020')
    fig=gcf;set(findall(fig,'-property','FontName'),'FontName','Arial','Fontsize',20)
end
%% Merging the surveys
Xtot=[X1mark;X2mark;X3mark;X4mark;X5mark;X6mark;X7mark;X8mark;X9mark;X10mark;X11mark;X12mark;X13mark;X14mark;X15mark]; % Append all surveys

[~,ia]=unique(Xtot(:,7),'stable');
Xtot_first=Xtot(ia,:); % first responses; unique respondents
Xtot_mean=NaN(size(Xtot_first));
for i=1:size(Xtot_first,1) % create matrix with mean values across surveys. Loop across all unique worker IDs
    Xtot_mean(i,:)=nanmean(Xtot(Xtot(:,7)==Xtot_first(i,7),:),1); % mean of responses with the same worker ID
end
Countrytot=[Country1;Country2;Country3;Country4;Country5;Country6;Country7;Country8;Country9;Country10;Country11;Country12;Country13;Country14;Country15];Countrytot_clean=Countrytot(ia,:);
ms=histc(histc(Xtot(:,7),unique(Xtot(:,7))),1:nrsurveys);
for i=1:nrsurveys
    disp(['If only counting the respondents'' first survey, the number of unique respondents included in survey ' num2str(i) ' = ' num2str(sum(Xtot_first(:,1)==i))]);
    disp(['If only counting the respondents'' first survey, the number of unique countries included in survey ' num2str(i) ' = ' num2str(length(unique(Countrytot_clean(Xtot_first(:,1)==i))))])
    disp([num2str(ms(i)) ' unique respondents completed ' num2str(i) ' surveys']);
end
disp(' ')
disp(['Total: Number of unique respondents = ' num2str(length(Xtot_first)) ])
disp(['Total: Number of unique respondents who completed two or more surveys = ' num2str(length(Xtot_first)-ms(1)) ])
Xtot_first(:,1)=[];Xtot_mean(:,1)=[]; % remove first column
disp(['Total: Number of unique countries = ' num2str(length(unique(Countrytot_clean)))])
disp(['Total: Number of unique respondents with numeric year = ' num2str(sum(Xtot_first(:,4)>0 & Xtot_first(:,4)~=9999.0001)) ])
disp(['Total: Number of unique respondents reporting ''never'' = ' num2str(sum(Xtot_first(~isnan(Xtot_first(:,4)),4)==9999.0001))])
disp(['Total: Number of unique respondents with a year = ' num2str(sum(Xtot_first(~isnan(Xtot_first(:,4)),4)>0))])
disp(['Total: Number of unique countries for respondents with a year = ' num2str(length(unique(Countrytot_clean(~isnan(Xtot_first(:,4))))))])
disp(['Total: Percentage males total = ' num2str(100*mean(Xtot_first(~isnan(Xtot_first(:,4)),2)-1))])
disp(['Total: Mean age = ' num2str(mean(Xtot_first(~isnan(Xtot_first(:,4)),3)) )])
disp(['Total: SD age = ' num2str(std(Xtot_first(~isnan(Xtot_first(:,4)),3)) )])
disp(['Total: P50 year = ' num2str(prctile(Xtot_first(~isnan(Xtot_first(:,4)),4),50))])
disp(['Total: P25 year = ' num2str(prctile(Xtot_first(~isnan(Xtot_first(:,4)),4),25))])
disp(['Total: P75 year = ' num2str(prctile(Xtot_first(~isnan(Xtot_first(:,4)),4),75))])
disp(['Total: % 2020 = ' num2str(100*sum(Xtot_first(~isnan(Xtot_first(:,4)),4)==2020)./sum(~isnan(Xtot_first(:,4)))) ])
disp(['Total: % 2030 = ' num2str(100*sum(Xtot_first(~isnan(Xtot_first(:,4)),4)==2030)./sum(~isnan(Xtot_first(:,4)))) ])
disp(['Total: % 2017-2029 = ' num2str(100*sum(Xtot_first(~isnan(Xtot_first(:,4)),4)>=2017 & Xtot_first(~isnan(Xtot_first(:,4)),4)<=2029)./sum(~isnan(Xtot_first(:,4)))) ])
disp(['Total: % 2075+  = ' num2str(100*sum(Xtot_first(~isnan(Xtot_first(:,4)),4)>=2075)./sum(~isnan(Xtot_first(:,4)))) ])
%% Create matrices of all participants across surveys
for survey=1:nrsurveys
    eval(['X' num2str(survey) 'B=NaN(size(Xtot_first,1),size(Xtot_first,2));'])
end
for i=1:length(Xtot_first) % loop over all respondents
    for survey=1:nrsurveys
        eval(['if sum(X' num2str(survey) '(:,6)==Xtot_first(i,6));X' num2str(survey) 'B(i,:)=X' num2str(survey) '(X' num2str(survey) '(:,6)==Xtot_first(i,6),:);end'])
    end
end
%% Longitudinal analysis
FL=NaN(size(X1B,1),2);
for i=1:size(X1B,1) % loop over all individual responses
    temp=[X1B(i,4) X2B(i,4) X3B(i,4) X4B(i,4) X5B(i,4) X6B(i,4) X7B(i,4) X8B(i,4) X9B(i,4) X10B(i,4) X11B(i,4) X12B(i,4) X13B(i,4) X14B(i,4) X15B(i,4)]; % vector of responses for respondent i
    temp(isnan(temp))=[]; % remove
    if length(temp)>=2
        FL(i,1)=temp(1);FL(i,2)=temp(end); % store first and last reported year of participant i
    end
end
FL2=FL(~isnan(sum(FL,2)),:); % remove people who did not add multiple years
disp('1. number of people with 2 or more years, 2. proportion same year in 1st and last survey, 3. proportion year higher in last survey than in 1st survey, 4. proportion year higher in 1st survey than in last survey')
disp([length(FL2) mean(FL2(:,1)==FL2(:,2)) mean(FL2(:,2)>FL2(:,1)) mean(FL2(:,2)<FL2(:,1))])
[p,~,stats]=signtest(FL2(:,1),FL2(:,2));
disp(['P from sign test = ' num2str(p)])
disp(stats)
disp('Correlation between first and last survey')
disp(corr(FL2(:,1),FL2(:,2),'type','spearman'))
%% Bar graphs with Spearmans correlation coefficients

% 1 = Instructions understood
% 2 = Gender
% 3 = Age
% 4 = Year
% 5 = Survey time
% 6 = Worker ID
% 8-14 = DBQ
% 15 = Google
% 16 = Tesla

[c,p,clow,chigh]=corrcoef(tiedrank([Xtot_first(:,4) Xtot_first(:,[2 3]) sum(Xtot_first(:,[9 10]),2) sum(Xtot_first(:,[8 11:14]),2) Xtot_first(:,[15 16])]),'rows','pairwise');
c=c(2:end,1);clow=clow(2:end,1);chigh=chigh(2:end,1);p=p(2:end,1);
n=sum(~isnan(Xtot_first(:,4)+[Xtot_first(:,[2 3]) sum(Xtot_first(:,[9 10]),2) sum(Xtot_first(:,[8 11:14]),2) Xtot_first(:,[15 16])]));
figure;hold on
barh(c,'facecolor',[0 144 189]/255);
for i=1:length(c)
    plot([chigh(i) chigh(i)],[i-0.15 i+.15],'k','linewidth',1)
    plot([clow(i) clow(i)],[i-0.15 i+.15],'k','linewidth',1)
    plot([clow(i) chigh(i)],[i i],'k','linewidth',1)
    text(0.052,i,['\it{N}\rm = ' num2str(n(i))])
end
box on
set(gca,'ytick',1:6,'yticklabel',{'Gender (1 = female, 2 = male)','Age (years)','Speeding violations score','Non-speeding violations score',...
    'Heard of Google Driverless car? (1 = no, 2 = yes)','Heard of Tesla Autopilot? (1 = no, 2 = yes)'},'ydir','reverse','xlim',[-0.2 0.05],'ylim',[.4 6.6])
set(findall(gcf,'-property','FontName'),'FontName','Arial','Fontsize',20)
xlabel('Spearman''s correlation coefficient')
%% Country analysis
UC=unique(Countrytot_clean); % unique countries
NC=NaN(length(UC),3);
XC=NaN(length(UC),size(Xtot_first,2));
XCmedian=NaN(length(UC),size(Xtot_first,2));
for i=1:length(UC) % loop across the unique countries
    temp=find(strcmp(Countrytot_clean,UC(i)));
    NC(i,1)=length(temp); % number of respondents per country
    NC(i,2)=sum(Xtot_mean(temp,4)>0); % number of respondents with year per country
    NC(i,3)=sum(~isnan(Xtot_mean(temp,8))); % number of respondents with DBQ score per country
    XC(i,1:size(Xtot_first,2))=nanmean(Xtot_mean(temp,:),1);     % first mean per respondent, then mean across respondents
    XCmedian(i,1:size(Xtot_first,2))=nanmedian(Xtot_mean(temp,:),1); % first mean per respondent, then median across respondents
end

UCdbq=UC(NC(:,3)>=TH)';
UC=UC(NC(:,2)>=TH)';
disp(['Respondents came from ' num2str(size(NC,1)) ' different countries'])
disp(['There were ' num2str(length(UC)) ' countries with ' num2str(TH) ' or more respondents who reported a year or ''never'''])
if FLAG==1
    %% Data taken from the WHO report "Global status report on road safety 2015"
    [WHO_ndata,~,WHO_alldata]=xlsread('WHO_data_2015_all_countries.xlsx','A2:H184');
    WHO_acc=NaN(length(UC),3);
    for i=1:length(UC) % loop across the unique countries
        temp=find(strcmp(WHO_alldata(:,2),UC(i)));
        if isempty(temp)==0
            WHO_acc(i,1:3)=WHO_ndata(temp,4:6); % Road traffic deaths
        end
    end
    %% Life expectancy, from Data WorldBank
    [LIFE_ndata0,~,LIFE_alldata]=xlsread('life_expectancy.xlsx','B5:BF252');
    LIFE_ndata=LIFE_ndata0(:,54);LIFE=NaN(length(UC),1);
    for i=1:length(UC) % loop across the unique countries
        temp=find(strcmp(LIFE_alldata(:,1),UC(i)));if ~isempty(temp);LIFE(i,1)=LIFE_ndata(temp,1);end
    end
    %% Cognitive ability, data from Rindermann 2007
    [COGN_ndata,~,COGN_alldata]=xlsread('Rindermann_2007_data.xlsx','A3:L196');
    COGN=NaN(length(UC),1);
    for i=1:length(UC) % loop across the unique countries
        temp=find(strcmp(COGN_alldata(:,2),UC(i)));if ~isempty(temp);COGN(i,1)=COGN_ndata(temp,9);end
    end
    %% Vehicle density, from Data WorldBank
    [VEH_ndata0,~,VEH_alldata]=xlsread('Veh_density.xlsx','B4:L201');
    VEH_ndata=nanmean(VEH_ndata0,2);VEH=NaN(length(UC),1);
    for i=1:length(UC) % loop across the unique countries
        temp=find(strcmp(VEH_alldata(:,1),UC(i)));if ~isempty(temp);VEH(i,1)=VEH_ndata(temp,1);end
    end
    %% Motorization rate, data taken from OICA
    [MOTORRATE_ndata0,~,MOTORRATE_alldata]=xlsread('Motorization_rate.xlsx','B2:C142');
    MOTORRATE_ndata=nanmean(MOTORRATE_ndata0,2);
    MOTORRATE=NaN(length(UC),1);
    for i=1:length(UC) % loop across the unique countries
        temp=find(strcmp(MOTORRATE_alldata(:,1),UC(i)));if ~isempty(temp);MOTORRATE(i,1)=MOTORRATE_ndata(temp,1);end
    end
    %% Median age, data taken from https://en.wikipedia.org/wiki/List_of_countries_by_median_age
    [AGE_ndata0, AGE_text, AGE_alldata]=xlsread('median_age','A1:B230');
    AGE_ndata=AGE_ndata0(:,1);
    AGE=NaN(length(UC),1);
    for i=1:length(UC) % loop across the unique countries
        temp=find(strcmp(AGE_alldata(:,1),UC(i)));if ~isempty(temp);AGE(i,1)=AGE_ndata(temp,1);end
    end
    
    NationalStatistics=[ WHO_acc(:,1) WHO_acc(:,3) COGN LIFE VEH AGE]; % 6 S: road traffic death rate, 7 S: GDP per capita, 8 S: educational performance, 9 S: life expectancy, 10 S: motor vehicle density, 11 S: median age
    save('NationalStatistics.mat','NationalStatistics')
end
load NationalStatistics % load the national statistics
%% Correlation matrix country level
x=XC(NC(:,3)>=TH,8:14); % 25 or more people with DBQ data
SpeedingV=zscore(mean(x(:,2:3),2));
NonSpeedingV=zscore(mean(x(:,[1 4:7]),2));
CMATR=[XCmedian(NC(:,2)>=TH,4) ... % 1 R: median year
    XC(NC(:,2)>=TH,[2 3]) ... % 2 R: gender (1 = female, 2 = male), 3 R: mean age
    XCmedian(NC(:,2)>=TH,4) XCmedian(NC(:,2)>=TH,4) ...
    NationalStatistics]; % 6 S: road traffic death rate, 7 S: GDP per capita, 8 S: educational performance, 9 S: life expectancy, 10 S: motor vehicle density, 11 S: median age
CMATR(:,2)=100*(CMATR(:,2)-1); % convert to % males
CMATR(NC(NC(:,2)>=TH,3)>=TH,4)=SpeedingV;
CMATR(NC(NC(:,2)>=TH,3)>=TH,5)=NonSpeedingV;
CMATR(NC(NC(:,2)>=TH,3)<TH,4:5)=NaN;
[c_CMATR,p_CMATR]=corr(CMATR,'type','spearman','rows','pairwise');
M='1.Year 2.Gender, 3.Age, 4.SpeedV 5.NonSpeedV 6.AccPopul 7.GDPcap 8.EducPerf 9.LifeExpec 10.VehicleDens 11.MedAge';
printmat(round(c_CMATR*100)/100,'Spearman correlation matrix at the country level', M,M)
disp('Sample sizes of variables of national matrix')
disp(sum(~isnan(CMATR)))
%%
W=[2000:1:3000 inf];
D=histc(Xtot_first(:,4),W);
figure;bar(W,D,'Linewidth',3);hold on
set(gca,'xlim',[2010 2205],'xtick',W(1:10:end),'xTickLabel',W(1:10:end))
xlabel('Reported year');ylabel('Number of respondents')
set(gca,'TickDir','out','LooseInset', [0.01 0.01 0.01 0.01])
set(findall(gcf,'-property','FontName'),'FontName','Arial','Fontsize',20)
%% Year vs. GDP per capita
figure;hold on;set(gca,'xscale','log');
for i=1:size(CMATR,1)
    semilogx(CMATR(i,7),CMATR(i,1),'ko','MarkerFaceColor','none','MarkerEdgeColor',[1 .5 0],'Markersize',10,'Linewidth',1.2)
end
h=findobj('FontName','Helvetica'); set(h,'FontSize',20,'Fontname','Arial')
xlabel('GDP per capita (US$, log scale)');ylabel('Median year')
axis([500 100000 2020 2050])
set(gca,'xTickLabel',{'1000','10000','100000'},'XTick',[1000 10000 100000])
grid on;box on;axis square
%% Non-speeding violations score vs. GDP per capita
figure;hold on;set(gca,'xscale','log');
for i=1:length(UCdbq)
    semilogx(CMATR(i,7),CMATR(i,5),'ko','MarkerFaceColor','none','MarkerEdgeColor',[1 .5 0],'Markersize',10,'Linewidth',1.2)
end
h=findobj('FontName','Helvetica'); set(h,'FontSize',20,'Fontname','Arial')
xlabel('GDP per capita (US$, log scale)');ylabel('Non-speeding violations score')
axis([500 100000 -2.5 2.5])
set(gca,'xTickLabel',{'1000','10000','100000'},'XTick',[1000 10000 100000])
grid on;box on;axis square
%% Control study with participants from a technical university
if FLAG==1
    [~,~,lab]=xlsread('lab_sm.xlsx','AD3:AD44');
    labyear=NaN(length(lab),1);
    for i=1:length(lab);try if strcmp(lab(i),'?');labyear(i)=NaN;else;labyear(i)=cell2mat(lab(i));end;catch error;labyear(i)=NaN;end;end % Year automated driving on roads
    for i=1:length(lab);try if strcmpi(lab(i),'never');labyear(i)=9999.0001;end;catch error;end;end % Year automated driving on roads (Participant reports 'never')
    [~,~,labgender]=xlsread('lab_sm.xlsx','K3:K44');
    labgender=1*strcmp(labgender,'Female')+1*strcmp(labgender,'female')+2*strcmp(labgender,'Male')+2*strcmp(labgender,'male')-1*strcmp(labgender,'No response')-1*strcmp(labgender,'I prefer not to respond'); % Gender
    [~,~,labage]=xlsread('lab_sm.xlsx','L3:L44');labage=cell2mat(labage);
    labpp=find(labyear>=2014);labpp(ismember(labpp,[2 5 11 30]))=[]; % remove authors / invalid participants
    save('control_study.mat','labyear','labgender','labpp','labage')
end
load control_study
disp(['Number of females in the control study = ' num2str(sum(labgender(labpp)==1))])
disp(['Number of males in the control study = ' num2str(sum(labgender(labpp)==2))])
disp(['Mean age in the control study = ' num2str(mean(labage(labpp)))])
disp(['SD age in the control study = ' num2str(std(labage(labpp)))])
disp(['P25 year in the control study = ' num2str(prctile(labyear(labpp),25))])
disp(['P50 year in the control study = ' num2str(prctile(labyear(labpp),50))])
disp(['P75 year in the control study = ' num2str(prctile(labyear(labpp),75))])
disp(['Minimum year in the control study = ' num2str(min(labyear(labpp)))])
disp('Number of respondents from the Netherlands')
disp(size(Xtot_first(strcmp(Countrytot_clean,'NLD'),:),1))
disp('Number of respondents from the Netherlands who reported a year of never')
disp(sum(~isnan(Xtot_first(strcmp(Countrytot_clean,'NLD'),4))))
disp('Median year in the Netherlands')
disp(prctile(Xtot_first(strcmp(Countrytot_clean,'NLD'),4),50))
%% Save data at the level of respondents
try
    delete('all_data_per_person_main_study.xls')
catch error
end
xlswrite('all_data_per_person_main_study.xls',[reshape(repmat(1:15,13,1),1,13*15);repmat(1:13,1,15);[X1B(:,[2 3 4 5 8:16]) X2B(:,[2 3 4 5 8:16]) X3B(:,[2 3 4 5 8:16]) X4B(:,[2 3 4 5 8:16])...
    X5B(:,[2 3 4 5 8:16])  X6B(:,[2 3 4 5 8:16]) X7B(:,[2 3 4 5 8:16]) X8B(:,[2 3 4 5 8:16])...
    X9B(:,[2 3 4 5 8:16]) X10B(:,[2 3 4 5 8:16]) X11B(:,[2 3 4 5 8:16]) X12B(:,[2 3 4 5 8:16])...
    X13B(:,[2 3 4 5 8:16]) X14B(:,[2 3 4 5 8:16]) X15B(:,[2 3 4 5 8:16])]],1,'B1')
xlswrite('all_data_per_person_main_study.xls',{'Survey number'},1,'A1')
xlswrite('all_data_per_person_main_study.xls',{'Variable number'},1,'A2')
xlswrite('all_data_per_person_main_study.xls',Countrytot_clean,1,'A3')
%% Save data at the level of respondents of the control study
try
    delete('all_data_per_person_control_study.xls')
catch error
end
xlswrite('all_data_per_person_control_study.xls',[labyear(labpp) labage(labpp) labgender(labpp)])
%% Save data at the level of countries
try
    delete('country_results.xls')
catch error
end
xlswrite('country_results.xls',[NC(NC(:,2)>=TH,:) CMATR],1,'B2')
xlswrite('country_results.xls',UC',1,'A2')
xlswrite('country_results.xls',{'Number of respondents','Number of respondents who reported a year or ''never''','Number of respondents with DBQ score','R: median year',...
    'R: % males','R: mean age','R: self-reported speeding violations score','R: self-reported non-speeding violations score','S: road traffic death rate per population','S: GDP per capita (US$)',...
    'S: educational performance','S: life expectancy','S: motor vehicle density per population','S: median age'},1,'B1')
